#!/bin/bash
# vim: dict=/usr/share/beakerlib/dictionary.vim cpt=.,w,b,u,t,i,k sts=4 sw=4 et
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   Description: network-qe lib
#   Author: Zhenjie Chen <zhchen@redhat.com>
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   Copyright (c) 2015 Red Hat, Inc. All rights reserved.
#
#   This copyrighted material is made available to anyone wishing
#   to use, modify, copy, or redistribute it subject to the terms
#   and conditions of the GNU General Public License version 2.
#
#   This program is distributed in the hope that it will be
#   useful, but WITHOUT ANY WARRANTY; without even the implied
#   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#   PURPOSE. See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public
#   License along with this program; if not, write to the Free
#   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#   Boston, MA 02110-1301, USA.
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#   library-prefix = network
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


true <<'=cut'
=pod

=head1 NAME

kernel/network - tools to setup testing network environment

=head1 DESCRIPTION

This is basic library for creation of network interfaces and working with them.

=cut

networkFindInclude()
{
    for kernelBase in $@
    do
        local CANDIDATE="$kernelBase/networking-common/include.sh"
	if [ -f "$CANDIDATE" ]
	then
                echo $CANDIDATE
                exit 0
        else
            CANDIDATE="$kernelBase/Library/networking-common/include.sh"
            if [ -f "$CANDIDATE" ]
            then
                    echo $CANDIDATE
                    exit 0
            fi
	fi
    done
    exit 1
}

if [ -n "$BASH_SOURCE" ]
then
	# BASH_SOURCE=*/kernel/Library/network/lib.sh
	# fetch kernel base, ie */kernel
	local kernelBase="$(dirname -- $(dirname -- $(dirname -- $BASH_SOURCE)))"
        local include=$(networkFindInclude "$kernelBase" /usr/share/beakerlib-libraries/kernel)
        
	[ -f "$include" ] && source "$include"
fi


<<'=cut'
=pod

=head1 VARIABLES

Below is the list of global variables. When writing a new library,
please make sure that all global variables start with the library
prefix to prevent collisions with other libraries.

=over

=item NETWORK_COMMONLIB_DIR

Directory to networking tools script

=back

=head1 FUNCTIONS

=head2 networkToolsEnable

Adds tools into path. After calling it, just call or source netns_?_net.sh.
On cleanup phase, call netns_clean.sh to remove created namespaces.

=over

=back
=cut
networkToolsEnable() {
	export PATH="$PATH:$networkLib/tools"
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#   Verification
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   This is a verification callback which will be called by
#   rlImport after sourcing the library to make sure everything is
#   all right. It makes sense to perform a basic sanity test and
#   check that all required packages are installed. The function
#   should return 0 only when the library is ready to serve.

networkLibraryLoaded() {
	[ -d "$networkLib" ]
}
