#!/usr/bin/bash
# vim: dict=/usr/share/beakerlib/dictionary.vim cpt=.,w,b,u,t,i,k
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   lib.sh of /CoreOS/mongodb/Library/basic
#   Description: Set of basic functions for mongodb
#   Author: Branislav Blaskovic <bblaskov@redhat.com>
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   Copyright (c) 2012 Red Hat, Inc. All rights reserved.
#
#   This copyrighted material is made available to anyone wishing
#   to use, modify, copy, or redistribute it subject to the terms
#   and conditions of the GNU General Public License version 2.
#
#   This program is distributed in the hope that it will be
#   useful, but WITHOUT ANY WARRANTY; without even the implied
#   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#   PURPOSE. See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public
#   License along with this program; if not, write to the Free
#   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#   Boston, MA 02110-1301, USA.
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#   library-prefix = mongodb
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

true <<'=cut'
=pod

=head1 NAME

mongodb/basic - set of basic functions for MongoDB

=head1 DESCRIPTION

This is basic library for MongoDB.

=cut

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#   Variables
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

true <<'=cut'
=pod

=head1 VARIABLES

Below is the list of global variables. When writing a new library,
please make sure that all global variables start with the library
prefix to prevent collisions with other libraries.

=over

=back

=cut

mongodbCollection=0
mongodbPkgPrefix=""
mongodbRootDir=""
mongodbVarDir=""
mongodbServiceName="mongod"

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#   Functions
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

true <<'=cut'
=pod

=head1 FUNCTIONS

=cut

mongodbStart() {
    rlRun "rlServiceStart $mongodbServiceName"
    rlRun "service $mongodbServiceName status"
    return $?
}

mongodbStop() {
    rlRun "rlServiceStop $mongodbServiceName"
    rlRun "service $mongodbServiceName status" 3
    return $?
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#   Verification
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   This is a verification callback which will be called by
#   rlImport after sourcing the library to make sure everything is
#   all right. It makes sense to perform a basic sanity test and
#   check that all required packages are installed. The function
#   should return 0 only when the library is ready to serve.

mongodbLibraryLoaded() {
    rlLogDebug "Library mongodb/basic is loaded."

    # recognize parameter to set collection via tcms case
    RUN_ON_DB=${RUN_ON_DB:-"$COLLECTIONS"}
    RUN_ON_DB=${RUN_ON_DB:-"$SYSPATHS"}

    # Set variables according to collection
    case "$RUN_ON_DB" in
       *rh-mongodb36*)
            mongodbCollection=1
            mongodbPkgPrefix="rh-mongodb36-"
            mongodbRootDir="/opt/rh/${mongodbPkgPrefix%-}/root"
            mongodbVarDir="/var/opt/rh/${mongodbPkgPrefix%-}"
            mongodbConfigDir="/etc/opt/rh/${mongodbPkgPrefix%-}"
            mongodbDataDir="${mongodbVarDir}/lib/mongodb"
            mongodbServiceName="${mongodbPkgPrefix}mongod"
            mongodbLog="$mongodbVarDir/log/mongodb/mongod.log"
            mongodbPidFile="$mongodbVarDir/run/mongodb/mongod.pid"
            mongodbLockFile="${mongodbDataDir}/mongod.lock"
            ;;
        *rh-mongodb34*)
            mongodbCollection=1
            mongodbPkgPrefix="rh-mongodb34-"
            mongodbRootDir="/opt/rh/${mongodbPkgPrefix%-}/root"
            mongodbVarDir="/var/opt/rh/${mongodbPkgPrefix%-}"
            mongodbConfigDir="/etc/opt/rh/${mongodbPkgPrefix%-}"
            mongodbDataDir="${mongodbVarDir}/lib/mongodb"
            mongodbServiceName="${mongodbPkgPrefix}mongod"
            mongodbLog="$mongodbVarDir/log/mongodb/mongod.log"
            mongodbPidFile="$mongodbVarDir/run/mongodb/mongod.pid"
            mongodbLockFile="${mongodbDataDir}/mongod.lock"
            ;;
        *rh-mongodb32*)
            mongodbCollection=1
            mongodbPkgPrefix="rh-mongodb32-"
            mongodbRootDir="/opt/rh/${mongodbPkgPrefix%-}/root"
            mongodbVarDir="/var/opt/rh/${mongodbPkgPrefix%-}"
            mongodbConfigDir="/etc/opt/rh/${mongodbPkgPrefix%-}"
            mongodbDataDir="${mongodbVarDir}/lib/mongodb"
            mongodbServiceName="${mongodbPkgPrefix}mongod"
            mongodbLog="$mongodbVarDir/log/mongodb/mongod.log"
            mongodbPidFile="$mongodbVarDir/run/mongodb/mongod.pid"
            mongodbLockFile="${mongodbDataDir}/mongod.lock"
            ;;
        *rh-mongodb30upg*)
            mongodbCollection=1
            mongodbPkgPrefix="rh-mongodb30upg-"
            mongodbRootDir="/opt/rh/${mongodbPkgPrefix%-}/root"
            mongodbVarDir="/var/opt/rh/${mongodbPkgPrefix%-}"
            mongodbConfigDir="/etc/opt/rh/${mongodbPkgPrefix%-}"
            mongodbDataDir="${mongodbVarDir}/lib/mongodb"
            mongodbServiceName="${mongodbPkgPrefix}mongod"
            mongodbLog="$mongodbVarDir/log/mongodb/mongod.log"
            mongodbPidFile="$mongodbVarDir/run/mongodb/mongod.pid"
            mongodbLockFile="${mongodbDataDir}/mongod.lock"
            ;;
        *rh-mongodb26*)
            mongodbCollection=1
            mongodbPkgPrefix="rh-mongodb26-"
            mongodbRootDir="/opt/rh/${mongodbPkgPrefix%-}/root"
            mongodbVarDir="/var/opt/rh/${mongodbPkgPrefix%-}"
            mongodbConfigDir="/etc/opt/rh/${mongodbPkgPrefix%-}"
            mongodbDataDir="${mongodbVarDir}/lib/mongodb"
            mongodbServiceName="${mongodbPkgPrefix}mongod"
            mongodbLog="$mongodbVarDir/log/mongodb/mongod.log"
            mongodbPidFile="$mongodbVarDir/run/mongodb/mongod.pid"
            mongodbLockFile="${mongodbDataDir}/mongod.lock"
            ;;
        *mongodb24*)
            mongodbCollection=1
            mongodbPkgPrefix="mongodb24-"
            mongodbRootDir="/opt/rh/${mongodbPkgPrefix%-}/root"
            mongodbVarDir="$mongodbRootDir/var"
            mongodbDataDir="${mongodbVarDir}/lib/mongodb"
            mongodbConfigDir="$mongodbRootDir/etc"
            mongodbServiceName="${mongodbPkgPrefix}mongodb"
            mongodbLog="/var/log/${mongodbPkgPrefix}mongodb/mongodb.log"
            mongodbPidFile="$mongodbVarDir/run/mongodb/mongodb.pid"
            mongodbLockFile="${mongodbDataDir}/mongod.lock"
            ;;
        *)
            mongodbCollection=0
            mongodbPkgPrefix=""
            mongodbRootDir=""
            mongodbVarDir="$mongodbRootDir/var"
            mongodbDataDir="${mongodbVarDir}/lib/mongodb"
            mongodbConfigDir="$mongodbRootDir/etc"
            mongodbServiceName="mongod"
            mongodbLog="$mongodbVarDir/log/mongodb/mongod.log"
            mongodbPidFile="$mongodbVarDir/run/mongodb/mongod.pid"
            mongodbLockFile="$mongodbVarDir/lib/mongodb/mongod.lock"
            ;;
    esac

    # Set variables according to syspaths
    case "$SYSPATHS" in
        *rh-mongodb36*)
            mongodbServiceName="mongod"
            ;;
        *rh-mongodb34*)
            mongodbServiceName="mongod"
            ;;
    esac

    # Write variables to screen
    rlLogDebug "*************** Library variables ***************"
    rlLogDebug "\$RUN_ON_DB              = $RUN_ON_DB"
    rlLogDebug "\$COLLECTIONS            = $COLLECTIONS"
    set | sed -ne '/^mongodb[a-zA-Z]\+=/s/=/="/' -e '/^mongodb[a-zA-Z]\+=/s/$/"/p' | while read line; do
        rlLogDebug "\$${line}";
    done
    rlLogDebug "*************** Library routines ****************"
    set | grep -E '^mongodb[a-zA-Z]+\s()' | grep -v "$FUNCNAME" | while read line; do
        rlLogDebug "$line";
    done
    rlLogDebug "*************************************************"
    return 0
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#   Authors
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

true <<'=cut'
=pod

=head1 AUTHORS

=over

=item *

Branislav Blaskovic <bblaskov@redhat.com>

=back

=cut
